"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/web.dom-collections.iterator.js");

require("core-js/modules/es.array.includes.js");

require("core-js/modules/es.string.includes.js");

require("core-js/modules/es.regexp.exec.js");

require("core-js/modules/es.string.replace.js");

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

require("../../styles/main.css");

var _Button = _interopRequireDefault(require("../Button/Button"));

var _SearchSuggestions = _interopRequireDefault(require("../SearchSuggestions/SearchSuggestions"));

var _Dummy = _interopRequireDefault(require("../../resources/Dummy.json"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const SearchBar = props => {
  // STATES
  // These states capture input text
  const [enteredTerm, setEnteredTerm] = (0, _react.useState)("");
  const [enteredLocation, setEnteredLocation] = (0, _react.useState)(""); // These states look at whether an input is focused

  const [termFocus, setTermFocus] = (0, _react.useState)(false);
  const [locationFocus, setLocationFocus] = (0, _react.useState)(false); // This state stores data to be passed to suggestions

  const [filteredData, setFilteredData] = (0, _react.useState)([]); // VARIABLES
  // Use these variables to specify what characters you'd like to filter in your inputs

  const termValidator = /[^a-zA-Z0-9\s]/gi;
  const locationValidator = /[^a-zA-Z0-9,-.]/gi; // FUNCTIONS
  // These functions handle and filter data based on inputs and are passed into their respective suggestion components as props

  const filterFunc = (database, searchTerm) => {
    const newFilter = database.filter(value => {
      return value.title.toLowerCase().includes(searchTerm.toLowerCase());
    });
    setFilteredData(newFilter);
  };

  const termChangeHandler = event => {
    const searchTerm = event.target.value.replace(termValidator, "");
    setEnteredTerm(searchTerm);
    filterFunc(_Dummy.default, searchTerm);
  };

  const locationChangeHandler = event => {
    const searchTerm = event.target.value.replace(locationValidator, "");
    setEnteredLocation(searchTerm);
    filterFunc(_Dummy.default, searchTerm);
  }; // This function prevents the suggestions from closing when clicked on by looking for a "no-close" class on them


  const showSuggestionHandler = event => {
    if (!event.target.classList.contains("no-close")) {
      setTermFocus(false);
      setLocationFocus(false);
    }
  }; // This function outputs inputted text in an object and clears the inputs


  const submitHandler = event => {
    event.preventDefault();

    if (enteredTerm && enteredLocation) {
      const searchData = {
        term: enteredTerm,
        location: enteredLocation
      };
    } // props.onSaveSearchData(searchData); This is a placeholder for whatever backend integration you'd like to place instead

  }; // These functions are passed as props to suggestions and allow items to be lifted into the input field when clicked on


  const termClickHandler = value => {
    setEnteredTerm(value);
  };

  const locationClickHandler = value => {
    setEnteredLocation(value);
  };

  return /*#__PURE__*/_react.default.createElement("div", {
    onClick: showSuggestionHandler
  }, /*#__PURE__*/_react.default.createElement("form", {
    onSubmit: submitHandler,
    className: "searchbar u-flexbox ".concat(enteredTerm.length != 0 && termFocus ? "searchbar-focus" : "")
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: "searchbar-inputs u-flexbox"
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: "u-flexbox searchbar-inputs__left"
  }, /*#__PURE__*/_react.default.createElement("input", {
    type: "text",
    className: "searchbar-input no-close",
    placeholder: "food pantry, daycare, counseling...",
    value: enteredTerm,
    onChange: termChangeHandler,
    onFocus: () => {
      setTermFocus(true);
      setLocationFocus(false);
    }
  }), /*#__PURE__*/_react.default.createElement("label", {
    className: "searchbar-text"
  }, "Find")), /*#__PURE__*/_react.default.createElement("div", {
    className: "searchbar-separator"
  }, "\xA0"), /*#__PURE__*/_react.default.createElement("div", {
    className: "u-flexbox searchbar-inputs__right"
  }, /*#__PURE__*/_react.default.createElement("input", {
    type: "text",
    className: "searchbar-input no-close",
    placeholder: "address, city, or zipcode",
    value: enteredLocation,
    onChange: locationChangeHandler,
    onFocus: () => {
      setLocationFocus(true);
      setTermFocus(false);
    }
  }), /*#__PURE__*/_react.default.createElement("label", {
    className: "searchbar-text"
  }, "Near"))), /*#__PURE__*/_react.default.createElement("div", {
    className: "searchbar-button"
  }, /*#__PURE__*/_react.default.createElement(_Button.default, {
    label: "Search",
    type: "submit",
    icon: "search",
    primary: "true"
  }))), enteredTerm.length != 0 && termFocus && /*#__PURE__*/_react.default.createElement(_SearchSuggestions.default, {
    className: "no-close",
    term: enteredTerm,
    searchTerm: filteredData,
    onTermClick: termClickHandler
  }), enteredLocation.length != 0 && locationFocus && /*#__PURE__*/_react.default.createElement(_SearchSuggestions.default, {
    className: "no-close",
    location: true,
    searchTerm: filteredData,
    onLocationClick: locationClickHandler
  }));
};

SearchBar.propTypes = {
  onSubmit: _propTypes.default.func
};
var _default = SearchBar;
exports.default = _default;